@@ -502,9 +502,13 @@ def create(
                 **common_parameters,
                 portfolio=parameters_to_use.get("portfolio"),
                 share_tag_options=parameters_to_use.get("share_tag_options"),
+                share_principals=parameters_to_use.get("share_principals"),
                 portfolio_task_reference=parameters_to_use.get(
                     "portfolio_task_reference"
                 ),
+                describe_portfolio_shares_task_ref=parameters_to_use.get(
+                    "describe_portfolio_shares_task_ref"
+                ),
             )
 
     elif section_name == constants.PORTFOLIO_SHARE_AND_ACCEPT_AWS_ORGANIZATIONS:
@@ -520,10 +524,14 @@ def create(
                 region=parameters_to_use.get("region"),
                 portfolio=parameters_to_use.get("portfolio"),
                 share_tag_options=parameters_to_use.get("share_tag_options"),
+                share_principals=parameters_to_use.get("share_principals"),
                 portfolio_task_reference=parameters_to_use.get(
                     "portfolio_task_reference"
                 ),
                 ou_to_share_with=parameters_to_use.get("ou_to_share_with"),
+                describe_portfolio_shares_task_ref=parameters_to_use.get(
+                    "describe_portfolio_shares_task_ref"
+                ),
             )
 
     elif section_name == constants.PORTFOLIO_GET_ALL_PRODUCTS_AND_THEIR_VERSIONS:
@@ -785,5 +793,16 @@ def create(
             parent_ou_task_ref=parameters_to_use.get("parent_ou_task_ref"),
         )
 
+    elif section_name == constants.DESCRIBE_PORTFOLIO_SHARES:
+        from servicecatalog_puppet.workflow.portfolio.sharing_management import (
+            describe_portfolio_shares_task,
+        )
+
+        return describe_portfolio_shares_task.DescribePortfolioSharesTask(
+            **common_parameters,
+            portfolio_task_reference=parameters_to_use.get("portfolio_task_reference"),
+            type=parameters_to_use.get("type"),
+        )
+
     else:
         raise Exception(f"Unknown section_name: {section_name}")
